FaceFrame class
Facial data from a single camera frame processed by the native pipeline.
Produced by the native layer at ~10–15fps (after frame dropping). Consumed by FaceGestureRecognizers in Dart. Approximate size: ~2KB per frame (without landmarks), ~10KB with landmarks.
Constructors
-
FaceFrame({required Duration timestamp, required bool isFaceDetected, required double faceConfidence, required Rect faceBoundingBox, required PoseAngles poseAngles, required Map<
FaceBlendshape, double> blendshapes, required List<FaceLandmark> ? landmarks, required ImageQualityMetrics quality}) -
const
-
FaceFrame.fromMap(Map<
String, dynamic> map) -
Deserializes a FaceFrame from the Map sent by the native platform channel.
factory
Properties
-
blendshapes
→ Map<
FaceBlendshape, double> -
final
- faceBoundingBox → Rect
-
final
- faceConfidence → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFaceDetected → bool
-
final
-
landmarks
→ List<
FaceLandmark> ? -
final
- poseAngles → PoseAngles
-
final
- quality → ImageQualityMetrics
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → Duration
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited